==> haskell-stmonadtrans-0.4.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.3
id: STMonadTrans-0.4.3-3tmnVgm5g675zsXJyaz72g
key: STMonadTrans-0.4.3-3tmnVgm5g675zsXJyaz72g
license: BSD3
maintainer: josef.svenningsson@gmail.com
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
author: Josef Svenningsson
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
abi: 6a83584c66ac53ee466777da4176150a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/STMonadTrans-0.4.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/STMonadTrans-0.4.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/STMonadTrans-0.4.3
hs-libraries: HSSTMonadTrans-0.4.3-3tmnVgm5g675zsXJyaz72g
depends:
    array-0.5.1.1 base-4.9.1.0 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.3
id: STMonadTrans-0.4.3-BjHxrfjqqDp1HRAb8EzNRn
key: STMonadTrans-0.4.3-BjHxrfjqqDp1HRAb8EzNRn
license: BSD3
maintainer: josef.svenningsson@gmail.com
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
author: Josef Svenningsson
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
abi: 08753d9debc0dcc0751ae45d1fae17ed
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/STMonadTrans-0.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/STMonadTrans-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/STMonadTrans-0.4.3
hs-libraries: HSSTMonadTrans-0.4.3-BjHxrfjqqDp1HRAb8EzNRn
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 array-0.5.2.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             array-0.5.2.0=044554210403f250e868a2183de060a9
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
